@@ -1,6 +1,10 @@
 package WebService::Raygun::Message;
-$WebService::Raygun::Message::VERSION = '0.027';
+$WebService::Raygun::Message::VERSION = '0.028';
+# VERSION
+
 use Mouse;
+use Try::Tiny;
+use Carp 'croak';
 
 =head1 NAME
 
@@ -24,7 +28,7 @@ WebService::Raygun::Message - A message to be sent to raygun.io
         ),
   );
 
-
+  # test stuff
 
 =head1 DESCRIPTION
 
@@ -128,9 +132,20 @@ If possible, the other data types are converted to an instance of this class.
 =cut
 
 has error => (
-    is     => 'rw',
-    isa    => 'MessageError',
-    coerce => 1,
+    is       => 'rw',
+    isa      => 'MessageError',
+    coerce   => 1,
+    default => sub {
+        my $exception;
+        try {
+            croak "Default error message. If you are seeing this,"
+            ."it means the developer has not passed in an error object.";
+        }
+        catch { 
+            $exception = $_; 
+        };
+        return $exception;
+    },
 );
 
 =head2 user
@@ -185,9 +200,10 @@ A I<request> object.  See L<WebService::Raygun::Message::Request|WebService::Ray
 =cut
 
 has request => (
-    is     => 'rw',
-    isa    => 'Request',
-    coerce => 1,
+    is      => 'rw',
+    isa     => 'Request',
+    coerce  => 1,
+    default => sub { return {}; },
 );
 
 =head2 environment
@@ -325,7 +341,7 @@ sub prepare_raygun {
             environment    => $self->environment->prepare_raygun,
             tags           => $self->tags,
             user           => $self->user->prepare_raygun,
-            response => {
+            response       => {
                 statusCode => $self->response_status_code,
             }
         }
@@ -358,6 +374,8 @@ sub prepare_raygun {
 
 =cut
 
+__PACKAGE__->meta->make_immutable();
+
 1;
 
 __END__
